@@ -14,8 +14,11 @@ static void update_avg(struct parser_base *p) {
             FIXED_1_ALPHA * p->avg_pkts_per_second;
     p->avg_pkts_per_second >>= FSHIFT;
 
-    p->pkts_last_second = p->pkts_this_second;
-    p->pkts_this_second = 0;
+    int success;
+    do {
+        p->pkts_last_second = p->pkts_this_second;
+        success = __sync_bool_compare_and_swap(&p->pkts_this_second, p->pkts_this_second, 0);
+    } while (!success);
 }
 
 static inline void update_flow_avg(struct flow *f) {
@@ -84,7 +87,7 @@ static void timeout_flows(struct parser_base *p, struct collector_info *info) {
         if ((ret = pthread_mutex_lock(&flow->mutex)) != 0) {
             ERROR(p, "Unable to acquire mutex on flow: %s", strerror(ret));
         }
-        
+
         update_flow_avg(flow);
         if (time > flow->expiry_time) {
             if (!(flow->info.flow_state & FLOW_STATE_ITERATED_OVER)) {
@@ -92,7 +95,7 @@ static void timeout_flows(struct parser_base *p, struct collector_info *info) {
                 kv_push(struct flow_id *, p->collector_list, id);
             }
         }
-        
+
         if ((ret = pthread_mutex_unlock(&flow->mutex)) != 0) {
             ERROR(p, "Unable to release flow mutex: %s", strerror(ret));
         }
@@ -138,7 +141,7 @@ int close_collector(struct parser_base *p) {
 
     if (p->collector_status == RUNNING) {
         INFO(p, "Joining collector thread");
-        
+
         if ((ret = pthread_join(p->collector, &status)) != 0) {
             ERROR(p, "Unable to join collector thread: %s", strerror(ret));
             pthread_mutex_unlock(&p->thread_status_mutex);
@@ -161,7 +164,7 @@ int close_collector(struct parser_base *p) {
         ERROR(p, "Unable to unlock thread status mutex: %s", strerror(ret));
         return -1;
     }
-    
+
     return 0;
 }
 
@@ -216,7 +219,7 @@ int init_collector(struct parser_base *p) {
         pthread_mutex_unlock(&p->thread_status_mutex);
         return -1;
     }
-    
+
     kv_init(p->collector_list);
 
     if ((ret = pthread_attr_init(&attr)) != 0) {
@@ -238,7 +241,7 @@ int init_collector(struct parser_base *p) {
         pthread_mutex_unlock(&p->thread_status_mutex);
         return -1;
     }
-    
+
     if ((ret = pthread_attr_destroy(&attr)) != 0) {
         ERROR(p, "Unable to destroy pthread attr: %s", strerror(ret));
         pthread_mutex_unlock(&p->thread_status_mutex);
