@@ -44,6 +44,7 @@ static PyStructSequence_Field info_ntuple_fields[] = {
     {"tcp_pkts", "Number of TCP pkts"},
     {"udp_pkts", "Number of UDP pkts"},
     {"time_collecting", "Time spent collecting"},
+    {"first_rx", "Timestamp of the first packet that was received"},
     {"live_captures", "Live capture sessions"},
     {NULL}
 };
@@ -51,7 +52,7 @@ static PyStructSequence_Desc info_ntuple_desc = {
     "fparser.FparserInfo",
     NULL,
     info_ntuple_fields,
-    7
+    8
 };
 
 static PyTypeObject fparser_cap_info_ntuple_type = {0, 0, 0, 0, 0, 0};
@@ -788,7 +789,10 @@ static PyObject *fparser_get_info(PyObject *self, PyObject *args) {
     PyStructSequence_SET_ITEM(info_ntuple, 5,
             PyLong_FromUnsignedLongLong(
             (unsigned long long) info.time_spent_collecting));
-    PyStructSequence_SET_ITEM(info_ntuple, 6, sniff_ntuple);
+    PyStructSequence_SET_ITEM(info_ntuple, 6,
+            PyLong_FromUnsignedLongLong(
+            (unsigned long long) info.first_rx_time));
+    PyStructSequence_SET_ITEM(info_ntuple, 7, sniff_ntuple);
 
     return info_ntuple;
 }
