@@ -31,6 +31,9 @@ void init_parser(struct parser_base *p) {
     p->collector_status = NOT_STARTED;
     p->dumper_status = NOT_STARTED;
     p->sniffer_status = NOT_STARTED;
+    
+    p->last_rx_time = UINT64_MAX;
+    p->first_rx_time = UINT64_MAX;
 }
 
 void close_parser(struct parser_base *p) {
@@ -389,10 +392,13 @@ void populate_parser_info(struct parser_base *p,
     size_t tcp_win_stride = 0, tcp_win_fields = 0;
     size_t tcp_flags_stride = 0, tcp_flags_fields = 0;
 
+    pthread_rwlock_wrlock(&p->flows_table_lock);
+    
     info->avg_pkts_per_sec = (float) ((double) p->avg_pkts_per_second /
             (double) FIXED_1);
     info->time_spent_collecting = p->time_spent_collecting;
     info->flows_collected = p->flows_collected;
+    info->first_rx_time = p->first_rx_time;
 
     info->tcp_flows = p->tcp_flows_inmem;
     info->udp_flows = p->udp_flows_inmem;
@@ -427,6 +433,8 @@ void populate_parser_info(struct parser_base *p,
             }
         }
     }
+    
+    pthread_rwlock_unlock(&p->flows_table_lock);
 
     info->ip_id_fields = ip_id_fields;
     info->ip_id_stride = ip_id_stride;
@@ -477,6 +485,8 @@ static inline void update_parser_bookkeeping(struct parser_base *p, uint64_t new
     do {
         res = __sync_bool_compare_and_swap(&p->last_rx_time, p->last_rx_time, new_timestamp);
     } while (!res);
+    
+    __sync_bool_compare_and_swap(&p->first_rx_time, UINT64_MAX, new_timestamp);
 }
 
 /**
